Package: ClustAll
Type: Package
Title: ClustAll: Data driven strategy to robustly identify
        stratification of patients within complex diseases
Version: 1.9.0
Authors@R: c(person("Asier", "Ortega-Legarreta", role = c("aut","cre"),  
           email = "aortegal@navarra.es", 
           comment = c(ORCID = "0009-0000-3563-5362")),
           person("Sara", "Palomino-Echeverria", role = c("aut"),  
           email = "spalomie@navarra.es"))
Imports: FactoMineR, bigstatsr, clValid, doSNOW, parallel, foreach,
        dplyr, fpc, mice, modeest, flock, networkD3, methods,
        ComplexHeatmap, cluster, RColorBrewer, circlize, grDevices,
        ggplot2, grid, stats, utils, pbapply
Suggests: RUnit, knitr, BiocGenerics, rmarkdown, BiocStyle, roxygen2
Description: Data driven strategy to find hidden groups of patients with complex
        diseases using clinical data. ClustAll facilitates the unsupervised 
        identification of multiple robust stratifications. ClustAll, is able to 
        overcome the most common limitations found when dealing with clinical 
        data (missing values, correlated data, mixed data types). 
Depends: R (>= 4.2.0)
License: GPL-2
Encoding: UTF-8
biocViews: Software, StatisticalMethod, Clustering, DimensionReduction,
        PrincipalComponent
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Packaged: 2026-04-28 21:56:36 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/ClustAll
git_branch: devel
git_last_commit: 4df6113
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Author: Asier Ortega-Legarreta [aut, cre] (ORCID:
    <https://orcid.org/0009-0000-3563-5362>),
  Sara Palomino-Echeverria [aut]
Maintainer: Asier Ortega-Legarreta <aortegal@navarra.es>
